/******************************************************************************		
*                                                                                   	
*       Copyright (C) 2008 Freescale Semiconductor, Inc.                            	
*       All Rights Reserved								              				
*														              					
* Filename:       LH64_ADC.c               											
*														              					
* Description:	  16-bit ADC Driver file for MCF51EM256	        	    	  	       						
*																						
* Notes:        																		
******************************************************************************/		

/* include files */
#include "derivative.h" /* include peripheral declarations */
#include "LH64_ADC.h"    


/******************************************************************************
Function Name	:	ADC_Init
Engineer      :	r54940
Date          :	04/08/08

Parameters		:	
Returns			  :	NONE
Notes         : Initialises ADC (includes Calibration)
******************************************************************************/
void ADC_Init( unsigned char CONFIG1, unsigned char CONFIG2, unsigned short COMPARE1, unsigned short COMPARE2, unsigned char STATUS2, unsigned char STATUS3, unsigned char STATUS1A, unsigned char STATUS1B)
{
	// Configure ADC for desired modes and options, but make sure hardware averaging is enabled and max for Cal.
  ADC_Config( CONFIG1, CONFIG2, COMPARE1, COMPARE2, STATUS2, 0x07, STATUS1A, STATUS1B);
  ADC_Cal ();
  // Redundant configuration call required to return Triggering and Hardware Averaging options to user-defined state.
  ADC_Config( CONFIG1, CONFIG2, COMPARE1, COMPARE2, STATUS2, STATUS3, STATUS1A, STATUS1B);
}

/******************************************************************************
Function Name	:	ADC_Config
Engineer      :	r54940
Date          :	04/08/08

Parameters		:	
Returns			  :	NONE
Notes         :	Configures ADC
******************************************************************************/
void ADC_Config(unsigned char CONFIG1, unsigned char CONFIG2, unsigned short COMPARE1, unsigned short COMPARE2, unsigned char STATUS2, unsigned char STATUS3, unsigned char STATUS1A, unsigned char STATUS1B)
{
  ADCCFG1= CONFIG1;
  ADCCFG2 = CONFIG2;
  ADCCV1 = COMPARE1;
  ADCCV2 = COMPARE2;
  ADCSC2 = STATUS2;
  ADCSC3 = STATUS3;
  ADCSC1A = STATUS1A;       /* Leave ADCH = 0x1F */
  ADCSC1B = STATUS1B;       /* Leave ADCH = 0x1F */
}
 
/******************************************************************************
Function Name	:	ADC_Cal
Engineer      :	r54940
Date          :	04/08/08

Parameters		:	
Returns			  :	NONE
Notes         :	Calibrates the ADC. Required after reset and before a conversion is initiated
******************************************************************************/
void ADC_Cal()
{

  volatile unsigned int cal_var;

  ADCSC2_ADTRG = 0;           // Enable Software Conversion Trigger for Calibration Process 
  ADCSC3_CAL = 1;             // Start CAL 


  while (ADCSC1A_COCOA == 0)
  	{
  	/* Wait for conversion to complete */
  	}	

  if (ADCSC3_CALF == 1)       // Check for Calibration fail error 
    {
    ADCSC3_CALF = CALF_FAIL;  // Clear Cal Fail flag
    //while(1);			 												// User will need to either re-attempt Calibration or generate fail indicator.
    }

  /* Calculate plus-side calibration as per 21.4.7 */
  cal_var = 0x00;

  cal_var =  (ADCCLP0); 
  cal_var += (ADCCLP1);
  cal_var += (ADCCLP2);
  cal_var += (ADCCLP3);
  cal_var += (ADCCLP4);
  cal_var += (ADCCLPS);

  cal_var = cal_var/2;
  
  cal_var += 0x8000; // Set MSB

  ADCPG = cal_var;

  /* Calculate minus-side calibration as per 21.4.7 */
  cal_var = 0x00;

 cal_var += (ADCCLM0) + (ADCCLM1) + (ADCCLM2) + 
  (ADCCLM3) + (ADCCLM4) + (ADCCLMS);

  cal_var = cal_var/2;

  cal_var += 0x8000; // Set MSB

  ADCMG = cal_var;

  /* Clear CAL bit */
  ADCSC3_CAL = 0;

}