/****************************************************************************************************/
/**
Copyright (c) 2008 Freescale Semiconductor
Freescale Confidential Proprietary
\file       TempMeasurement.c
\brief      
\author     Freescale Semiconductor
\author     Guadalajara Applications Laboratory RTAC Americas
\author     
\version    0.1
\date       October/2008
*/
/****************************************************************************************************/
/*                                                                                                  */
/* All software, source code, included documentation, and any implied know-how are property of      */
/* Freescale Semiconductor and therefore considered CONFIDENTIAL INFORMATION.                       */
/* This confidential information is disclosed FOR DEMONSTRATION PURPOSES ONLY.                      */
/*                                                                                                  */
/* All Confidential Information remains the property of Freescale Semiconductor and will not be     */
/* copied or reproduced without the express written permission of the Discloser, except for copies  */
/* that are absolutely necessary in order to fulfill the Purpose.                                   */
/*                                                                                                  */
/* Services performed by FREESCALE in this matter are performed AS IS and without any warranty.     */
/* CUSTOMER retains the final decision relative to the total design and functionality of the end    */
/* product.                                                                                         */
/* FREESCALE neither guarantees nor will be held liable by CUSTOMER for the success of this project.*/
/*                                                                                                  */
/* FREESCALE disclaims all warranties, express, implied or statutory including, but not limited to, */
/* implied warranty of merchantability or fitness for a particular purpose on any hardware,         */
/* software ore advise supplied to the project by FREESCALE, and or any product resulting from      */
/* FREESCALE services.                                                                              */
/* In no event shall FREESCALE be liable for incidental or consequential damages arising out of     */
/* this agreement. CUSTOMER agrees to hold FREESCALE harmless against any and all claims demands or */
/* actions by anyone on account of any damage,or injury, whether commercial, contractual, or        */
/* tortuous, rising directly or indirectly as a result of the advise or assistance supplied CUSTOMER*/ 
/* in connectionwith product, services or goods supplied under this Agreement.                      */
/*                                                                                                  */
/****************************************************************************************************/

/*****************************************************************************************************
* Include files
*****************************************************************************************************/
#include "TempMeasurement.h"

/*****************************************************************************************************
* Declaration of module wide FUNCTIONs - NOT for use in other modules
*****************************************************************************************************/
void InitTempSensorParameters(void);
signed int GetTemperature(void);

/*****************************************************************************************************
* Definition of module wide MACROs / #DEFINE-CONSTANTs - NOT for use in other modules
*****************************************************************************************************/

/*****************************************************************************************************
* Declaration of module wide TYPEs - NOT for use in other modules
*****************************************************************************************************/


/*****************************************************************************************************
* Definition of module wide VARIABLEs - NOT for use in other modules
*****************************************************************************************************/
UINT16 gu16ADCVDD = 300;
UINT8  gu8TempMetricSystem = _CELSIUS_;

extern signed int   Temperature;
extern unsigned int ADCVTemp25;
extern unsigned int CalculatedVDD;
extern unsigned int TempSlopeHigh;
extern unsigned int TempSlopeLow;
extern unsigned char FTRIM_ROOM;
extern unsigned char ICSTRM_ROOM ;

/*****************************************************************************************************
* Definition of module wide (CONST-) CONSTANTs - NOT for use in other modules
*****************************************************************************************************/
/**
* \brief Celsius table 26 valid lines + 2 lines out of valid border
*/
const UINT16 _adc_12bit_Celsius[] @0xFE60 = 
{0,                                            // out of valid table
 1188,1229,1270,1311,1354,1397,1440,1487,1526,1570,    // 10 - 19C valid table
 1615,1659,1703,1747,1792,1837,1881,1925,1969,2014,    // 20 - 29C valid table
 2058,2101,2144,2187,2229,2272,                        // 30 - 35C valid table
 2273                                                  // >= 36C out of valid table
};

/**
* \brief Fahrenheit table 46 valid lines + 2 lines out of valid border
*/
const UINT16 _adc_12bit_Fahrenheit[] @0xFE00 = 
{0,                                            // out of valid table
  1188,1211,1233,1256,1279,1302,1325,1349,1373,1397, // valid table
  1421,1444,1468,1492,1517,1541,1566,1590,1615,1639, // valid table
  1664,1688,1713,1738,1762,1787,1812,1837,1862,1886, // valid table
  1910,1935,1959,1984,2009,2033,2058,2082,2106,2129, // valid table
  2153,2177,2201,2225,2248,2272,                     // valid table
  2273                                               // out of valid table
};

/**
* \brief Index for the tables with the ADC Indexes equivalent to the temperature
*/
const UINT16* IndexTable[_TOTAL_METRIC_SYSTEMS_] =
{
  (UINT16*)(&_adc_12bit_Celsius),
  (UINT16*)(&_adc_12bit_Fahrenheit)  
};

/**
* \brief Temperature table sizes
*/
const UINT8 IndexTablesSize[_TOTAL_METRIC_SYSTEMS_] = 
{
  sizeof(_adc_12bit_Celsius)/sizeof(UINT16), 
  sizeof(_adc_12bit_Fahrenheit)/sizeof(UINT16)
};

/**
* \brief Initial temperature value
*/
const UINT8 TempOffset[_TOTAL_METRIC_SYSTEMS_] = 
{
  CELSIUS_DEGREES_START,
  FAHRENHEIT_DEGREES_START
};

/*****************************************************************************************************
* Code of project wide FUNCTIONS
*****************************************************************************************************/

void InitTempSensorParameters(void)
{
  int ADC16_data;
  /*
   * We start making a conversion of the BandGap channel to know the value of the VDD; the BandGap reference is
   * typically = 1.17 volts, so we can calculate the VDD used at the time
   */
  ADCSC1A = 0x1B;
  do{
  	// Wait for conversion to complete 
    }while (ADCSC2_ADACT == 1); 
  /* 
   * Bandgap voltage is 1.17 volts. The operation will return the value of the voltage with one integer 
   * and three decimal in a fixed point representation (3333 is 3.333 volts)
   *      [10 bits]
   * VDD = 1024 * 1.17 / ADCRA -> VDD * 1000 = 1024 * 1.17 * 1000 / ADCRA = 1198080 / ADCRA
   *      [16 bits]
   * VDD = 65536 * 1.17 / ADCRA -> VDD * 1000 = 65536 * 1.17 * 1000 / ADCRA = 76677120 / ADCRA
   * bandgap is alway 1.17 v- the result in the ADC varries depending on the state of VDD.
   * measure bandgap = ADC channel 0x1B - Single ended 16 bit reault (ie 0x416A) 
   */
  ADC16_data = ADCRA;
  CalculatedVDD = (unsigned int)(((unsigned long)(1198080)) / ADC16_data);

  /*
   * VTemp25 = .7012 volts -> VDD = xVolts = 1024 in ADC Result register
   * VTemp25 = (.7012 * 1024) / VDD -> VADCTemp25 = 718029 / CalculatedVDD (Calc VDD is VDD * 1000) 
   */
  ADCVTemp25 = (unsigned int)(718029 / CalculatedVDD);

  /*
   * TempSlopeHigh = 1.769mV/C  (Temp > 25C)
   * TempSlopeHigh * 10000 = .001769 * 1024 * 10000 / VDD = 18110 / VDD
   * TempSlopeLow  = 1.646mV/C  (Temp < 25C)
   * TempSlopeLow * 10000  = .001646 * 1024 * 10000 / VDD = 16855 / VDD
   */
  TempSlopeHigh = (unsigned int)(1811000 / CalculatedVDD);
  TempSlopeLow  = (unsigned int)(1685500 / CalculatedVDD);
}




signed int GetTemperature(void)
{
  signed int Temp,TMP1,TMP2,TMP3,ADC16_Data;
  /* Start an ADC conversion in the Temp Sensor channel*/
  ADCSC1A = 0x1A;
 do{
  	// Wait for conversion to complete 
    }while (ADCSC2_ADACT == 1); 
  /*
   * VTemp25 is the value that the ADC should return for a temperature of 25C
   * TempSlope used is TempSlope * 10000 / CalculatedVDD
   * If we use (ADCR - ADCVTemp25) * 1000 and then we divide it by the TempSlope used we will have a value in C * 10 
   */
  ADC16_Data = ADCRA;
  if (ADC16_Data >= ADCVTemp25)
  {
    /* Temperature = 25 - ((VTemp - VTemp25) / m)*/
    TMP1 = (ADC16_Data- ADCVTemp25);
    TMP2 = (TMP1 * 1000);
    TMP3 = (TMP2 / TempSlopeLow);
    Temp = (25 - TMP3);
  }
  else    /* if (ADC16_Data< ADCVTemp25)      */
  {
    /* Temperature = 25 + ((VTemp25 - VTemp) / m)*/
    TMP1 = (ADCVTemp25 - ADC16_Data) * 1000;
    TMP2 = (TMP1 * 1000);
    TMP3 = (TMP2 /TempSlopeHigh);
    Temp = 25 + TMP3;
  }
  // keep Temp in bounds 0 to 50 degrees.
  if (Temp > 50){
    Temp = 49;
  }else if (Temp <0){
    Temp = 0;
  }
  /* We can return the value in 8 bit since we used it in 16 bit only temprarily */
  return ((signed int)(Temp));
}
